[llvm-commits] [zorg] r107288 - /zorg/trunk/lnt/lnt/tests/nt.py

Daniel Dunbar daniel at zuster.org
Wed Jun 30 09:23:09 PDT 2010


Author: ddunbar
Date: Wed Jun 30 11:23:08 2010
New Revision: 107288

URL: http://llvm.org/viewvc/llvm-project?rev=107288&view=rev
Log:
LNT/nt: Don't accept 9999 as a valid tag number for llvm-gcc.

Modified:
    zorg/trunk/lnt/lnt/tests/nt.py

Modified: zorg/trunk/lnt/lnt/tests/nt.py
URL: http://llvm.org/viewvc/llvm-project/zorg/trunk/lnt/lnt/tests/nt.py?rev=107288&r1=107287&r2=107288&view=diff
==============================================================================
--- zorg/trunk/lnt/lnt/tests/nt.py (original)
+++ zorg/trunk/lnt/lnt/tests/nt.py Wed Jun 30 11:23:08 2010
@@ -393,10 +393,11 @@
             run_info['run_order'] = run_info['cc_src_revision']
 
         # Otherwise, if this is a production compiler, look for a source tag. We
         # don't accept 0 as a valid source tag, since that is what llvm-gcc
         # defaults to when no build number is given.
         elif (run_info.get('cc_build') == 'PROD' and
-              run_info.get('cc_src_tag') != '0' and
+              (run_info.get('cc_src_tag') != '0' or
+               run_info.get('cc_src_tag') != '9999') and
               run_info.get('cc_src_tag','').isdigit()):
             run_info['run_order'] = run_info['cc_src_tag']
 
@@ -393,10 +393,11 @@
 
         # Otherwise, if this is a production compiler, look for a source tag. We
-        # don't accept 0 as a valid source tag, since that is what llvm-gcc
-        # defaults to when no build number is given.
+        # don't accept 0 or 9999 as valid source tag, since that is what
+        # llvm-gcc builds use when no build number is given.
         elif (run_info.get('cc_build') == 'PROD' and





More information about the llvm-commits mailing list